@@ -39,18 +39,18 @@ class KolfWindow : public KXmlGuiWindow
 
 public:
 	KolfWindow();
-	~KolfWindow();
+	~KolfWindow() override;
 
 	void openUrl(const QUrl &url);
 
-public slots:
+public Q_SLOTS:
 	void closeGame();
 	void updateModified(bool);
 
 protected:
 	bool queryClose() Q_DECL_OVERRIDE;
 
-protected slots:
+protected Q_SLOTS:
 	void startNewGame();
 	void loadGame();
 	void tutorial();
